# pylanco <a href="https://pypi.org/project/pylanco/">[0.1.8]</a>

## Usage:
> Update conda.yaml with the following: 
```yaml
- pylanco==0.1.8
```
---
## Documentation

- [📄](./ERP.md): ERP Documentation
- [📄](./PC.md): PC Documentation
